@@ -2,6 +2,7 @@ import collections
 import logging
 import base64
 import json
+import os
 
 import six
 
@@ -54,6 +55,20 @@ class Check(object):
             ret['timeout'] = timeout
         return ret
 
+    @classmethod
+    def tcp(klass, host, port, interval, timeout=None):
+        """
+        Attempt to establish a tcp connection to the specified *host* and
+        *port* at a specified *interval* with optional *timeout*
+        """
+        ret = {
+            'tcp': '{host:s}:{port:d}'.format(host=host, port=port),
+            'interval': interval
+        }
+        if timeout:
+            ret['timeout'] = timeout
+        return ret
+
     @classmethod
     def ttl(klass, ttl):
         """
@@ -62,6 +77,21 @@ class Check(object):
         """
         return {'ttl': ttl}
 
+    @classmethod
+    def docker(klass, container_id, shell, script, interval):
+        """
+        Invoke *script* packaged within a running docker container with
+        *container_id* at a specified specified *interval* on the configured
+        *shell* using the Docker Exec API
+        """
+        ret = {
+            'docker_container_id': container_id,
+            'shell': shell,
+            'script': script,
+            'interval': interval
+        }
+        return ret
+
     @classmethod
     def _compat(
             self,
@@ -120,6 +150,8 @@ def callback(
         else:
             data = response
         if one:
+            if data == []:
+                data = None
             if data is not None:
                 data = data[0]
         if map:
@@ -159,8 +191,16 @@ class Consul(object):
 
         # TODO: Status
 
+        if os.getenv('CONSUL_HTTP_ADDR'):
+            host, port = os.getenv('CONSUL_HTTP_ADDR').split(':')
+        use_ssl = os.getenv('CONSUL_HTTP_SSL')
+        if use_ssl is not None:
+            scheme = 'https' if use_ssl == 'true' else 'http'
+        if os.getenv('CONSUL_HTTP_SSL_VERIFY') is not None:
+            verify = os.getenv('CONSUL_HTTP_SSL_VERIFY') == 'true'
+
         self.http = self.connect(host, port, scheme, verify)
-        self.token = token
+        self.token = os.getenv('CONSUL_HTTP_TOKEN', token)
         self.scheme = scheme
         self.dc = dc
         assert consistency in ('default', 'consistent', 'stale'), \
@@ -507,7 +547,6 @@ class Consul(object):
         takes on the burden of registering with the Catalog and performing
         anti-entropy to recover from outages.
         """
-        # TODO: join, force-leave
         def __init__(self, agent):
             self.agent = agent
             self.service = Consul.Agent.Service(agent)
@@ -590,6 +629,44 @@ class Consul(object):
                 '/v1/agent/maintenance',
                 params=params)
 
+        def join(self, address, wan=False):
+            """
+            This endpoint instructs the agent to attempt to connect to a
+            given address.
+
+            *address* is the ip to connect to.
+
+            *wan* is either 'true' or 'false'. For agents running in server
+            mode, 'true' causes the agent to attempt to join using the WAN
+            pool. Default is 'false'.
+            """
+
+            params = {}
+
+            if wan:
+                params['wan'] = 1
+
+            return self.agent.http.get(
+                lambda x: x.code == 200,
+                '/v1/agent/join/%s' % address,
+                params=params)
+
+        def force_leave(self, node):
+            """
+            This endpoint instructs the agent to force a node into the left
+            state. If a node fails unexpectedly, then it will be in a failed
+            state. Once in the failed state, Consul will attempt to reconnect,
+            and the services and checks belonging to that node will not be
+            cleaned up. Forcing a node into the left state allows its old
+            entries to be removed.
+
+            *node* is the node to change state for.
+            """
+
+            return self.agent.http.get(
+                lambda x: x.code == 200,
+                '/v1/agent/force-leave/%s' % node)
+
         class Service(object):
             def __init__(self, agent):
                 self.agent = agent
@@ -624,7 +701,8 @@ class Consul(object):
                 provided.
 
                 An optional health *check* can be created for this service is
-                one of `Check.script`_, `Check.http`_, or `Check.ttl`_.
+                one of `Check.script`_, `Check.http`_, `Check.tcp`_,
+                `Check.ttl`_ or `Check.docker`_.
 
                 *token* is an optional `ACL token`_ to apply to this request.
                 Note this call will return successful even if the token doesn't
@@ -726,8 +804,8 @@ class Consul(object):
 
                 *name* is the name of the check.
 
-                *check* is one of `Check.script`_, `Check.http`_, or
-                `Check.ttl`_ and is required.
+                *check* is one of `Check.script`_, `Check.http`_, `Check.tcp`_
+                `Check.ttl`_ or `Check.docker`_ and is required.
 
                 If the optional *check_id* is not provided it is set to *name*.
                 *check_id* must be unique for this agent.
