@@ -12,10 +12,12 @@ __all__ = ['Consul']
 
 
 class HTTPClient(object):
-    def __init__(self, host='127.0.0.1', port=8500, scheme='http'):
+    def __init__(self, host='127.0.0.1', port=8500, scheme='http',
+                 verify=True):
         self.host = host
         self.port = port
         self.scheme = scheme
+        self.verify = verify
         self.base_uri = '%s://%s:%s' % (self.scheme, self.host, self.port)
         self.client = httpclient.AsyncHTTPClient()
 
@@ -45,15 +47,17 @@ class HTTPClient(object):
 
     def put(self, callback, path, params=None, data=''):
         uri = self.uri(path, params)
-        request = httpclient.HTTPRequest(uri, method='PUT', body=data)
+        request = httpclient.HTTPRequest(uri, method='PUT', body=data,
+                                         validate_cert=self.verify)
         return self._request(callback, request)
 
     def delete(self, callback, path, params=None):
         uri = self.uri(path, params)
-        request = httpclient.HTTPRequest(uri, method='DELETE')
+        request = httpclient.HTTPRequest(uri, method='DELETE',
+                                         validate_cert=self.verify)
         return self._request(callback, request)
 
 
 class Consul(base.Consul):
-    def connect(self, host, port, scheme):
-        return HTTPClient(host, port, scheme)
+    def connect(self, host, port, scheme, verify=True):
+        return HTTPClient(host, port, scheme, verify=verify)
